<?php

/*
   File: dining-scrape.php
   Scrapes dining1.rutgers.edu/FoodPro, which was poorly written in XML.
   This script takes the XML provided by FoodPro, pretty-fies it, places it
   into an array, then puts it into JSON.

   This file compiles all locations into one file, including all available
   menus for the day. Note that these are defined in the script. This
   needs to change if any of the FoodPro GET variables change.
*/

$basedir = dirname(__FILE__);

include_once($basedir . '/include/config.php');
include_once($basedir . '/include/xml2array.php');

isset($GLOBALS['CONFIG']) or die("FATAL: " . __FILE__ . ":" . __LINE__. ": config parsing failed\n"); 
if (ini_get('date.timezone') == '') die ("FATAL: " . __FILE__ . ": requires that date.timezone has a value in php.ini\n");

$output = array();
$spaces = array("    ", "   ", "  "); // whoever made foodpro doesn't know proper formatting of english...
$locations = array("01","04","05","03");
$meal_names = array("breakfast","lunch","dinner", "knight room");

// i is location id
for ($i = 0; $i < count($locations); $i++)
{
   // for now, we're just gonna get the location configuration
   $result = file_get_contents('http://dining1.rutgers.edu/FoodPro/menu.asp?LocationNUM=' . $locations[$i]);
   $result = xml2array($result);

   $output[$i]['location_name'] = $result['rss']['channel']['location']['value'];
   $output[$i]['date'] = date("D, M j, Y");

   if ($output[$i]['location_name'] == "Cooper Dining Hall")
   {
      // FIXME: FIX GARBAGE FROM DINING
      $output[$i]['location_name'] = "Livingston Dining Commons";
   }

   // j is meal id
   for ($j = 0; $j < count($meal_names); $j++)
   {
      $output[$i]['meals'][$j]['meal_name'] = ucwords($meal_names[$j]);

      // get what they're serving for that meal
      $result = file_get_contents('http://dining1.rutgers.edu/FoodPro/menu.asp?LocationNUM=' . $locations[$i] . '&mealName=' . urlencode(ucwords($meal_names[$j])));
      $result = xml2array($result);

//    if (count($result['rss']['channel']['item']) == 0)
      if (!isset($result['rss']['channel']['item']))
      {
         // meal is unavailable
         $output[$i]['meals'][$j]['meal_avail'] = false;
      }
      else
      {
         $output[$i]['meals'][$j]['meal_avail'] = true;

         $k = -1;   // k is the category (header) #
         $r = 0;    // row number
         foreach ($result['rss']['channel']['item'] as $item)   // foreach piece of food (or header)
         {
            if (preg_match("/--/", $item['description']['value']))
            {
               $k++;      // increment # of categories
               $output[$i]['meals'][$j]['genres'][$k]['genre_name'] = str_replace($spaces, " and ", ucwords(strtolower(trim(preg_replace("/--/","",$item['description']['value'])))));
               $output[$i]['meals'][$j]['genres'][$k]['genre_name'] = str_replace("&amp;", "", $output[$i]['meals'][$j]['genres'][$k]['genre_name']);
               $r = 0;    // reset row # (because a new cat just started)
            } else {
               $output[$i]['meals'][$j]['genres'][$k]['items'][$r] = str_replace($spaces, " ", ucwords(strtolower($item['description']['value'])));
               $r++;      // increment row #
            }
         }
         if ($k === -1)
         {
            $output[$i]['meals'][$j]['genres'][0]['genre_name'] = "Menu";
            $output[$i]['meals'][$j]['genres'][0]['items'] = $output[$i]['meals'][$j]['genres'][-1]['items'];
            unset($output[$i]['meals'][$j]['genres'][-1]);
         }
      }
   }
}

// we need to make sure data is good from FoodPro, if not, we won't write to file.
$broken = false;
for($i = 0; $i < count($locations); $i++)
{
   if ($output[$i]['location_name'] == null)
   {
      $broken = true;
   }
}

if (!$broken)
{
   $output = json_encode($output);

   $file = fopen($GLOBALS['CONFIG']['temp_dir'] . '/0.0/rutgers-dining.txt', 'w');
   fwrite($file, $output);
   fclose($file);

   chmod($GLOBALS['CONFIG']['temp_dir'] . '/0.0/rutgers-dining.txt', 0644);
   rename($GLOBALS['CONFIG']['temp_dir'] . '/0.0/rutgers-dining.txt', $GLOBALS['CONFIG']['web_dir'] . '/0.0/rutgers-dining.txt');
}
?>
