<?php

/*
   File: line2stops-times.php
   Author: Steven Lu <sjlu@nbcs.rutgers.edu>
   This file is spawned by generator.php

   This takes in a route argument, which means
   it only parses one at a time (unless threads
   are spawned)

   This will look at the route, grab all the stops
   on that route. Then it will take each stop+route
   combination and iterate the web for it's available
   predictions. All of which is placed into a nice array
   which is then printed out as JSON at the end.

   Nextbus has a lot of different conditions based on
   a lot of factors (such as if predictable, multiple stop
   ids for the same stop name, not running, etc), which
   this file can handle. [read comments for more info]

   0.1: added in agency cli param
*/

$agency = $argv[1];
$_GET['route'] = $argv[2];

$basedir=dirname(__FILE__);

include_once($basedir . '/../include/config.php');
include_once($basedir . '/../include/xml2array.php');

isset($GLOBALS['CONFIG']) or die("FATAL: " . __FILE__ . ":" . __LINE__. ": config parsing failed\n");

//$pid = pcntl_fork();
$nextbus_url = 'http://webservices.nextbus.com/service/publicXMLFeed';

// taking in the vehicle list, seeing if there are any busses running for that route.
$vehicle_list = file_get_contents($nextbus_url . '?a=' . $agency . '&command=vehicleLocations&r=' . $_GET['route'] . '&t=0');
if ($vehicle_list === false) die();
$vehicle_list = xml2array($vehicle_list);
$vehicle_list = $vehicle_list['body'];

$predictions = array();

$predictions['running'] = true;
if (!isset($vehicle_list['vehicle']))
{
   $predictions['running'] = false;
}

// if there are vehicles, we go on...
if ($predictions['running'])
{
   $predictions['running'] = true;
   // getting the stops for our route.
   $route_stops = file_get_contents($nextbus_url . '?a=' . $agency . '&command=routeConfig&r=' . $_GET['route']);
   if ($route_stops === false) die();
   $route_stops = xml2array($route_stops);   
   
   // beginning to iterate each stop on that route.
   $route_stops = $route_stops['body'];
   for ($i = 0; $i < count($route_stops['route']['stop']); $i++)
   {
      // If the stop doesn't have an ID, ignore it, it's bad.
      if (!isset($route_stops['route']['stop'][$i]['attr']['stopId']))
         continue;

      // grabbing route+stop cobination for its stops.
      $route_stop_predic_list = file_get_contents ($nextbus_url . '?a=' . $agency . '&command=predictions&r=' . $_GET['route'] . '&stopId=' . $route_stops['route']['stop'][$i]['attr']['stopId']);
      if ($route_stop_predic_list === false) die();
      $route_stop_predic_list = xml2array($route_stop_predic_list);
      $route_stop_predic_list = $route_stop_predic_list['body']['predictions'];


      //if (!isset($route_stop_predic_list['body'])) echo $route_stop['route']['stop'][$i]['attr']['stopId'];
      // now sometimes there's a stop with multiple directions/stops, so we need to error handle that.
      if (isset($route_stop_predic_list[0]))
      {
         for ($k = 0; $k < count($route_stop_predic_list); $k++)
         {
            if ($route_stops['route']['stop'][$i]['attr']['tag'] == $route_stop_predic_list[$k]['attr']['stopTag'])
            {
               $route_stop_predic_list = $route_stop_predic_list[$k];
               break;
            }
         }
      }

      // if no directions, it's bad, don't use it.
      if (!isset($route_stop_predic_list['direction']))
         continue;
      
      $route_stop_predic_list = $route_stop_predic_list['direction']['prediction'];
     
      if (count($route_stop_predic_list) == 0)
      {
         $predictions['times'][$i] = null;
      }      

      if (count($route_stop_predic_list) == 1)
      {
         $predictions['times'][$i][0] = $route_stop_predic_list['attr']['minutes'];
      }
      else
      {
         // yay! we have predictions, so we can put it into our output
         for ($j = 0; $j < count($route_stop_predic_list); $j++)
            $predictions['times'][$i][$j] = $route_stop_predic_list[$j]['attr']['minutes'];
      }
   }
   
}

// last but not least, encode and write.
$json = json_encode($predictions);

if ($agency == 'rutgers') // 0.0 specific
{
   $file = fopen($GLOBALS['CONFIG']['temp_dir'] . '/0.0/nextbus/'.$_GET['route'].'.txt', 'w');
   fwrite($file, $json);
   fclose($file);
}

$file = fopen($GLOBALS['CONFIG']['temp_dir'] . '/0.1/nextbus/' . $agency . '/'.$_GET['route'].'.txt', 'w');
fwrite($file, $json);
fclose($file);

?>
